import requestAuth from '@/utils/requestAuth'

// 获取角色列表
export function fetchList(query) {
  return requestAuth({
    url:  '/sysOrgRole/list',
    method: 'get',
    params: query
  })
}

// 获取角色树和该角色对应的资源
export function getRoleResTree(query) {
  return requestAuth({
    url:  '/sysOrgRoleRes/list',
    method: 'get',
    params: query
  })
}

// 创建角色
export function createRole(data) {
  return requestAuth({
    url:  '/sysOrgRole/save',
    method: 'post',
    data
  })
}

// 更新角色
export function updateRole(data) {
  return requestAuth({
    url:  '/sysOrgRole/update',
    method: 'post',
    data
  })
}

// 获取角色详情
export function getRoleById(id) {
  return requestAuth({
    url:  '/sysOrgRole/info/' + id,
    method: 'get'
  })
}

// 删除角色信息
export function deleteRole(id) {
  return requestAuth({
    url:  '/sysOrgRole/delete',
    method: 'delete',
    data: [id]
  })
}

// 保存角色资源关系
export function saveRoleRes(data) {
  return requestAuth({
    url:  '/sysOrgRoleRes/save',
    method: 'post',
    data
  })
}

// 保存角色的数据权限
export function saveRoleDataAuth(data) {
  return requestAuth({
    url:  '/sysRoleSensitiveAuth/update',
    method: 'put',
    data
  })
}